struct Bucket {
layouts: HashSet<DescriptorSetLayout>,
pools: Vec<Pool>,
available_sets: u32,
allocated_sets: u32,
}Expand description
Keeps track of all pools created with this bucket’s BucketKey.
Fields
layouts: HashSet<DescriptorSetLayout>We keep track of all descriptor set layouts that might use this bucket. If the set becomes empty, the bucket is destroyed.
pools: Vec<Pool>available_sets: u32allocated_sets: u32Implementations